==> igniteui-webcomponents-core-3.2.2.tgz: package/esm5/lib/NativeUIDropDown.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { NativeUIComponent } from "./NativeUIComponent";
import { NativeUIDisplayDensity_$type } from "./NativeUIDisplayDensity";
import { enumGetBox, EnumUtil, markType } from "./type";
/**
 * @hidden
 */
var NativeUIDropDown = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(NativeUIDropDown, _super);
    function NativeUIDropDown() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.aq = null;
        return _this;
    }
    NativeUIDropDown.prototype.get_c = function () {
        return 4;
    };
    Object.defineProperty(NativeUIDropDown.prototype, "ap", {
        get: function () {
            var a = this.o(1);
            return a == null ? 1 : EnumUtil.getEnumValue(NativeUIDisplayDensity_$type, a);
        },
        set: function (a) {
            this.ad(1, enumGetBox(NativeUIDisplayDensity_$type, a));
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NativeUIDropDown.prototype, "ar", {
        get: function () {
            return this.aq;
        },
        set: function (a) {
            var b = this.aq;
            this.aq = a;
            if (this.aq != null) {
                this.w(3, this.aq);
            }
            else {
                this.ab(3, b);
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NativeUIDropDown.prototype, "at", {
        get: function () {
            var a = this.o(7);
            return a;
        },
        set: function (a) {
            this.ad(7, a);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NativeUIDropDown.prototype, "as", {
        get: function () {
            var a = this.o(6);
            return a;
        },
        set: function (a) {
            this.ad(6, a);
        },
        enumerable: true,
        configurable: true
    });
    NativeUIDropDown.$t = markType(NativeUIDropDown, 'NativeUIDropDown', NativeUIComponent.$);
    return NativeUIDropDown;
}(NativeUIComponent));
export { NativeUIDropDown };

==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/NativeUIDropDown.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { NativeUIComponent } from "./NativeUIComponent";
import { NativeUIDisplayDensity_$type } from "./NativeUIDisplayDensity";
import { enumGetBox, EnumUtil, markType } from "./type";
/**
 * @hidden
 */
var NativeUIDropDown = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(NativeUIDropDown, _super);
    function NativeUIDropDown() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.au = null;
        return _this;
    }
    NativeUIDropDown.prototype.get_c = function () {
        return 4;
    };
    Object.defineProperty(NativeUIDropDown.prototype, "at", {
        get: function () {
            var a = this.o(1);
            return a == null ? 1 : EnumUtil.getEnumValue(NativeUIDisplayDensity_$type, a);
        },
        set: function (a) {
            this.af(1, enumGetBox(NativeUIDisplayDensity_$type, a));
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NativeUIDropDown.prototype, "av", {
        get: function () {
            return this.au;
        },
        set: function (a) {
            var b = this.au;
            this.au = a;
            if (this.au != null) {
                this.x(3, this.au);
            }
            else {
                this.ad(3, b);
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NativeUIDropDown.prototype, "ax", {
        get: function () {
            var a = this.o(7);
            return a;
        },
        set: function (a) {
            this.af(7, a);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NativeUIDropDown.prototype, "aw", {
        get: function () {
            var a = this.o(6);
            return a;
        },
        set: function (a) {
            this.af(6, a);
        },
        enumerable: true,
        configurable: true
    });
    NativeUIDropDown.$t = markType(NativeUIDropDown, 'NativeUIDropDown', NativeUIComponent.$);
    return NativeUIDropDown;
}(NativeUIComponent));
export { NativeUIDropDown };
